Page 15 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 15

Home

    Mystery Babylon

    And upon her forehead was a name written,
    MYSTERY, BABYLON THE GREAT, THE
    MOTHER OF HARLOTS AND ABOMINATIONS OF
    THE EARTH.

    And the woman which thou sawest is that great city,
    which reigneth over the kings of the earth.
    Revelation 17:18

    Although the Babylon of Revelation is literally
    identified as, "Babylon The Great" with the word
    "Mystery," attached to it, for the purpose of illustration
    and comparison, we have chosen to identify it as
    "Mystery Babylon" as is done in the New International
    Version of the Bible. Clearly, both terms describe the

    Babylon of Revelation.

    The writer of the Book of Revelation gave no
    geographical location or time period of the great city that
    was described as reigning over the kings of the earth. He
    did, however, give a detailed description of its character

    The word "mystery" as applied to Babylon is a Greek
    word £v0T1,91t0Vv (Musterion) that carries the idea of

    10

    Chapter 2

    Revelation 17:5

    and its deeds. |